@@ -151,24 +151,17 @@ class Polynomial:
 
             tobe_inserted, i = Polynomial.inclusion(new_list, mono2, i)
 
-            if not (tobe_inserted):
+            if not tobe_inserted:
                 j = j + 1
                 continue
 
-            # handle case where first list is shorter
-            # by just appending what remains of the
-            # other list of monomials
-            # FIXME FOR WHAT ?
-            # if new_list == []:
-            #     new_list = new_list + polynomial.list[j:]
-
             # handle case where first list is shorter
             # by just appending what remains of the
             # other list of monomials
             if i == len(new_list):
                 for m in polynomial.list[j:]:
                     tobe_inserted, i = Polynomial.inclusion(new_list, m, i)
-                    if (tobe_inserted):
+                    if tobe_inserted:
                         new_list = new_list + [m]
                 break
 
@@ -187,11 +180,9 @@ class Polynomial:
                 j = j + 1
 
             # when both list heads are the same
-            # recompute scalar and move to next
-            # element
+            # recompute scalar and move to next element
             else:
-                new_list[i].scalar = \
-                    sum_mwp(mono1.scalar, mono2.scalar)
+                new_list[i].scalar = sum_mwp(mono1.scalar, mono2.scalar)
                 j = j + 1
 
         sorted_monomials = Polynomial.sort_monomials(new_list)
@@ -268,16 +259,12 @@ class Polynomial:
             if i not in index_list:
                 index_list.append(i)
 
-        if len(self.list) > 1000 or len(polynomial.list) > 1000:
-            logger.debug(f'p1 {len(self.list)}, p2: {len(polynomial.list)}')
-
         # 3: start main part
         result = []
         while index_list:
             # 4. get first element and append to result
             # 5. remove from index and table
             smallest = index_list.pop(0)
-            # TODO 
             mono2 = table[smallest].pop(0)
             tobe_inserted, _ = Polynomial.inclusion(result, mono2)
             if tobe_inserted:
@@ -494,9 +481,6 @@ class Polynomial:
         Before returning, if the list is empty, the result produces a
             0-monomial.
 
-        Arguments:
-            polynomial: from which to remove zeros
-
         Returns:
             polynomial with list of monomials for which zeros are
             removed, unless 0 is the only monomial.
@@ -510,3 +494,35 @@ class Polynomial:
             self.list = filtered_monomials
 
         return self
+
+    @staticmethod
+    def from_scalars(index: int, *scalars: str) -> Polynomial:
+        """Build a polynomial of multiple monomials with deltas.
+
+        Example:
+
+            arguments:
+
+                - index: 5
+                - scalars: m, w, p
+
+            result:
+
+            ```Python
+            Polynomial(
+                Monomial('m', [(0, 5), (1, 5), (2, 5)]),
+                Monomial('w', [(0, 5), (1, 5), (2, 5)]),
+                Monomial('p', [(0, 5), (1, 5), (2, 5)]))
+            ```
+
+        Arguments:
+            index: delta index
+            scalars: scalar values
+
+        Returns:
+             Generated polynomial
+         """
+
+        monomials = [Monomial(scalar, [(number, index)])
+                     for number, scalar in enumerate(scalars)]
+        return Polynomial(monomials)
