@@ -2,7 +2,7 @@ from pymwp import Analysis, Polynomial
 from .mocks.ast_mocks import \
     INFINITE_2C, NOT_INFINITE_2C, IF_WO_BRACES, IF_WITH_BRACES, \
     VARIABLE_IGNORED, OTHER_BRACES_ISSUES, BASICS_ASSIGN_VALUE, PARAMS, \
-    FUNCTION_CALL
+    FUNCTION_CALL, INFINITE_8C
 
 
 def test_analyze_infinite2():
@@ -10,8 +10,8 @@ def test_analyze_infinite2():
     relation, combinations, infty = Analysis.run(INFINITE_2C, no_save=True)
 
     assert infty  # result should be infinite
-    assert combinations == []  # no combinations since it is infinite
-    assert set(relation.variables) == {'X0', 'X1'}  # expected variables
+    assert combinations is None  # no combinations since it is infinite
+    assert relation is None  # no relation since infinite
 
 
 def test_analyze_non_infinite_2():
@@ -32,6 +32,12 @@ def test_analyze_non_infinite_2():
     assert str(relation.matrix[0][0].list[2]) == 'w.delta(2,0)'
 
 
+def test_analyze_infinite_8():
+    """Check analysis result for infinite/infinite_8.c"""
+    _, _, infty = Analysis.run(INFINITE_8C, no_save=True)
+    assert infty
+
+
 def test_analyze_if_braces_do_not_matter():
     """If...else block with single-statement, with or without curly braces,
      should give the same analysis result."""
@@ -53,7 +59,7 @@ def test_analyze_if_braces_do_not_matter():
 
 def test_analyze_variable_ignore():
     """Analysis picks up variable on left of assignment,
-    see issue #11: https://github.com/seiller/pymwp/issues/11 """
+    see issue #11: https://github.com/statycc/pymwp/issues/11 """
     relation, combinations = Analysis.run(VARIABLE_IGNORED, no_save=True)[:2]
 
     assert combinations == [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2],
@@ -82,7 +88,7 @@ def test_analyze_variable_ignore():
 
 def test_extra_braces_are_ignored():
     """Analysis ignores superfluous braces in C program,
-    see issue: #25: https://github.com/seiller/pymwp/issues/25"""
+    see issue: #25: https://github.com/statycc/pymwp/issues/25"""
     relation, combinations = Analysis.run(OTHER_BRACES_ISSUES, no_save=True)[
                              :2]
 
@@ -96,7 +102,7 @@ def test_extra_braces_are_ignored():
 def test_assigning_value_yields_matrix_result():
     """Analyzing should yield a result with matrix for programs with
     declaration only.
-    issue #43: https://github.com/seiller/pymwp/issues/43"""
+    issue #43: https://github.com/statycc/pymwp/issues/43"""
     relation = Analysis.run(BASICS_ASSIGN_VALUE, no_save=True)[0]
 
     assert relation.variables == ['y']
@@ -105,7 +111,7 @@ def test_assigning_value_yields_matrix_result():
 
 def test_analysis_identifies_function_params():
     """Analysis will identify variables from function declaration
-    issue #51: https://github.com/seiller/pymwp/issues/51
+    issue #51: https://github.com/statycc/pymwp/issues/51
     """
     relation = Analysis.run(PARAMS, no_save=True)[0]
 
@@ -117,8 +123,8 @@ def test_analysis_returns_all_functions():
     evaluation of each function (example 5)
     """
     result = Analysis.run(FUNCTION_CALL, no_save=True)
-    f, _, _ = result['f']
+    _, _, f_infty = result['f']
     foo, _, _ = result['foo']
 
-    assert set(f.variables) == {'X1', 'X2'}
+    assert f_infty
     assert set(foo.variables) == {'X1', 'X2', 'X3'}
